/*
  SPDX-FileCopyrightText: 2025-2026 Laurent Montel <montel@kde.org>

  SPDX-License-Identifier: GPL-2.0-or-later
*/
#pragma once

#include <QString>

namespace GenericNetworkModelInfosDelegateUtils
{
[[nodiscard]] qreal basicMargin();
[[nodiscard]] int textMargin();
[[nodiscard]] qreal rectRoundValue();
[[nodiscard]] int categoryOffset();
[[nodiscard]] int categoryMarginText();
[[nodiscard]] int spacingBetweenTextAndCategories();
};
