// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "autogeneratetext_ollamacloud_debug.h"


Q_LOGGING_CATEGORY(AUTOGENERATETEXT_OLLAMACLOUD_LOG, "org.kde.kf.autogeneratetext.ollamacloud", QtInfoMsg)

