/****************************************************************************
** Meta object code from reading C++ file 'ollamacommonsettings.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../ktextaddons-2.0.2/textautogeneratetext/plugins/ollamacommon/ollamacommonsettings.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ollamacommonsettings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20OllamaCommonSettingsE_t {};
} // unnamed namespace

template <> constexpr inline auto OllamaCommonSettings::qt_create_metaobjectdata<qt_meta_tag_ZN20OllamaCommonSettingsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OllamaCommonSettings",
        "ShareNameType",
        "DoNotShare",
        "UserName",
        "FullName",
        "KeepAliveType",
        "Unknown",
        "KeepAliveForever",
        "UnloadAfterUse",
        "SetTimer"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ShareNameType'
        QtMocHelpers::EnumData<enum ShareNameType>(1, 1, QMC::EnumIsScoped).add({
            {    2, ShareNameType::DoNotShare },
            {    3, ShareNameType::UserName },
            {    4, ShareNameType::FullName },
        }),
        // enum 'KeepAliveType'
        QtMocHelpers::EnumData<enum KeepAliveType>(5, 5, QMC::EnumIsScoped).add({
            {    6, KeepAliveType::Unknown },
            {    7, KeepAliveType::KeepAliveForever },
            {    8, KeepAliveType::UnloadAfterUse },
            {    9, KeepAliveType::SetTimer },
        }),
    };
    return QtMocHelpers::metaObjectData<OllamaCommonSettings, qt_meta_tag_ZN20OllamaCommonSettingsE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OllamaCommonSettings::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20OllamaCommonSettingsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20OllamaCommonSettingsE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20OllamaCommonSettingsE_t>.metaTypes,
    nullptr
} };

QT_WARNING_POP
