/****************************************************************************
** Meta object code from reading C++ file 'textautogeneratetextinstancesmanagerlistview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ktextaddons-2.0.2/textautogeneratetext/widgets/instancesmanager/textautogeneratetextinstancesmanagerlistview.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'textautogeneratetextinstancesmanagerlistview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20TextAutoGenerateText44TextAutoGenerateTextInstancesManagerListViewE_t {};
} // unnamed namespace

template <> constexpr inline auto TextAutoGenerateText::TextAutoGenerateTextInstancesManagerListView::qt_create_metaobjectdata<qt_meta_tag_ZN20TextAutoGenerateText44TextAutoGenerateTextInstancesManagerListViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TextAutoGenerateText::TextAutoGenerateTextInstancesManagerListView",
        "removeInstance",
        "",
        "uuid",
        "editInstance",
        "markAsDefaultChanged",
        "addInstance"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'removeInstance'
        QtMocHelpers::SignalData<void(const QByteArray &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QByteArray, 3 },
        }}),
        // Signal 'editInstance'
        QtMocHelpers::SignalData<void(const QByteArray &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QByteArray, 3 },
        }}),
        // Signal 'markAsDefaultChanged'
        QtMocHelpers::SignalData<void(const QByteArray &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QByteArray, 3 },
        }}),
        // Signal 'addInstance'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TextAutoGenerateTextInstancesManagerListView, qt_meta_tag_ZN20TextAutoGenerateText44TextAutoGenerateTextInstancesManagerListViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TextAutoGenerateText::TextAutoGenerateTextInstancesManagerListView::staticMetaObject = { {
    QMetaObject::SuperData::link<QListView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20TextAutoGenerateText44TextAutoGenerateTextInstancesManagerListViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20TextAutoGenerateText44TextAutoGenerateTextInstancesManagerListViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20TextAutoGenerateText44TextAutoGenerateTextInstancesManagerListViewE_t>.metaTypes,
    nullptr
} };

void TextAutoGenerateText::TextAutoGenerateTextInstancesManagerListView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TextAutoGenerateTextInstancesManagerListView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->removeInstance((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); break;
        case 1: _t->editInstance((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); break;
        case 2: _t->markAsDefaultChanged((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); break;
        case 3: _t->addInstance(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TextAutoGenerateTextInstancesManagerListView::*)(const QByteArray & )>(_a, &TextAutoGenerateTextInstancesManagerListView::removeInstance, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TextAutoGenerateTextInstancesManagerListView::*)(const QByteArray & )>(_a, &TextAutoGenerateTextInstancesManagerListView::editInstance, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TextAutoGenerateTextInstancesManagerListView::*)(const QByteArray & )>(_a, &TextAutoGenerateTextInstancesManagerListView::markAsDefaultChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TextAutoGenerateTextInstancesManagerListView::*)()>(_a, &TextAutoGenerateTextInstancesManagerListView::addInstance, 3))
            return;
    }
}

const QMetaObject *TextAutoGenerateText::TextAutoGenerateTextInstancesManagerListView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TextAutoGenerateText::TextAutoGenerateTextInstancesManagerListView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20TextAutoGenerateText44TextAutoGenerateTextInstancesManagerListViewE_t>.strings))
        return static_cast<void*>(this);
    return QListView::qt_metacast(_clname);
}

int TextAutoGenerateText::TextAutoGenerateTextInstancesManagerListView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QListView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void TextAutoGenerateText::TextAutoGenerateTextInstancesManagerListView::removeInstance(const QByteArray & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void TextAutoGenerateText::TextAutoGenerateTextInstancesManagerListView::editInstance(const QByteArray & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void TextAutoGenerateText::TextAutoGenerateTextInstancesManagerListView::markAsDefaultChanged(const QByteArray & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void TextAutoGenerateText::TextAutoGenerateTextInstancesManagerListView::addInstance()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
