/*
  SPDX-FileCopyrightText: 2025-2026 Laurent Montel <montel@kde.org>

  SPDX-License-Identifier: GPL-2.0-or-later
*/

#include "ollamacommonmodelinfosdelegateutils.h"
#include <qtypes.h>

qreal OllamaCommonModelInfosDelegateUtils::basicMargin()
{
    return 8;
}

int OllamaCommonModelInfosDelegateUtils::textMargin()
{
    return 15;
}

qreal OllamaCommonModelInfosDelegateUtils::rectRoundValue()
{
    return 5;
}

int OllamaCommonModelInfosDelegateUtils::categoryOffset()
{
    return 10;
}

int OllamaCommonModelInfosDelegateUtils::categoryMarginText()
{
    return 10;
}

int OllamaCommonModelInfosDelegateUtils::spacingBetweenTextAndCategories()
{
    return 10;
}
