/****************************************************************************
** Meta object code from reading C++ file 'texttospeechwidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ktextaddons-2.0.2/textedittexttospeech/texttospeechwidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'texttospeechwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20TextEditTextToSpeech18TextToSpeechWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto TextEditTextToSpeech::TextToSpeechWidget::qt_create_metaobjectdata<qt_meta_tag_ZN20TextEditTextToSpeech18TextToSpeechWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TextEditTextToSpeech::TextToSpeechWidget",
        "stateChanged",
        "",
        "TextEditTextToSpeech::TextToSpeechWidget::State",
        "state",
        "changeVisibility",
        "aboutToSynthesize",
        "qsizetype",
        "id",
        "say",
        "text",
        "slotStateChanged",
        "TextEditTextToSpeech::TextToSpeech::State",
        "State",
        "Stop",
        "Play",
        "Pause"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'stateChanged'
        QtMocHelpers::SignalData<void(TextEditTextToSpeech::TextToSpeechWidget::State)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'changeVisibility'
        QtMocHelpers::SignalData<void(bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Signal 'aboutToSynthesize'
        QtMocHelpers::SignalData<void(qsizetype)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'say'
        QtMocHelpers::SlotData<void(const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'slotStateChanged'
        QtMocHelpers::SlotData<void(TextEditTextToSpeech::TextToSpeech::State)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'State'
        QtMocHelpers::EnumData<enum State>(13, 13, QMC::EnumFlags{}).add({
            {   14, State::Stop },
            {   15, State::Play },
            {   16, State::Pause },
        }),
    };
    return QtMocHelpers::metaObjectData<TextToSpeechWidget, qt_meta_tag_ZN20TextEditTextToSpeech18TextToSpeechWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TextEditTextToSpeech::TextToSpeechWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20TextEditTextToSpeech18TextToSpeechWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20TextEditTextToSpeech18TextToSpeechWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20TextEditTextToSpeech18TextToSpeechWidgetE_t>.metaTypes,
    nullptr
} };

void TextEditTextToSpeech::TextToSpeechWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TextToSpeechWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->stateChanged((*reinterpret_cast<std::add_pointer_t<TextEditTextToSpeech::TextToSpeechWidget::State>>(_a[1]))); break;
        case 1: _t->changeVisibility((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->aboutToSynthesize((*reinterpret_cast<std::add_pointer_t<qsizetype>>(_a[1]))); break;
        case 3: _t->say((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->slotStateChanged((*reinterpret_cast<std::add_pointer_t<TextEditTextToSpeech::TextToSpeech::State>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TextToSpeechWidget::*)(TextEditTextToSpeech::TextToSpeechWidget::State )>(_a, &TextToSpeechWidget::stateChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TextToSpeechWidget::*)(bool )>(_a, &TextToSpeechWidget::changeVisibility, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TextToSpeechWidget::*)(qsizetype )>(_a, &TextToSpeechWidget::aboutToSynthesize, 2))
            return;
    }
}

const QMetaObject *TextEditTextToSpeech::TextToSpeechWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TextEditTextToSpeech::TextToSpeechWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20TextEditTextToSpeech18TextToSpeechWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int TextEditTextToSpeech::TextToSpeechWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void TextEditTextToSpeech::TextToSpeechWidget::stateChanged(TextEditTextToSpeech::TextToSpeechWidget::State _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void TextEditTextToSpeech::TextToSpeechWidget::changeVisibility(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void TextEditTextToSpeech::TextToSpeechWidget::aboutToSynthesize(qsizetype _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
