/*
  SPDX-FileCopyrightText: 2025-2026 Laurent Montel <montel@kde.org>

  SPDX-License-Identifier: GPL-2.0-or-later
*/
#include "textautogeneratefilecache.h"

using namespace Qt::Literals::StringLiterals;
using namespace TextAutoGenerateText;
TextAutoGenerateFileCache::TextAutoGenerateFileCache() = default;

TextAutoGenerateFileCache::~TextAutoGenerateFileCache() = default;

QString TextAutoGenerateFileCache::cacheFilePath(const QByteArray &attachmentId)
{
    // TODO
    return {};
}
