// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "textautogeneratetextcore_memory_debug.h"


Q_LOGGING_CATEGORY(TEXTAUTOGENERATETEXT_CORE_MEMORY_LOG, "org.kde.kf.textautogeneratetext.memory", QtInfoMsg)

